@@ -165,7 +165,7 @@ class AssemblySummary:
         self.download_by_accession(out_dir, accessions)
 
     def filter_accession_by_taxid(self, taxids=[]):
-        df = self.assembly_summary_df
+        df = self.assembly_summary_df.dropna(subset=["taxid_lineage", "taxid"])
         accessions = [
             a
             for a in df.apply(
@@ -301,7 +301,6 @@ class AssemblySummary:
                 results = {}
                 count = 0
                 for future in concurrent.futures.as_completed(futures):
-
                     org_name, ftp_path = futures[future]
                     pbar.set_description(f"{org_name} is downloaded")
                     returncode = future.result()
@@ -314,6 +313,7 @@ class AssemblySummary:
                         pbar.set_description(f"sleep 30s...")
                         sleep(30)
                         count = 0
+
         success = True
         download_status_f = out_dir / "download_status.txt"
         with open(download_status_f, "w") as f:
@@ -337,7 +337,7 @@ class AssemblySummary:
         if accessions:
             filter_df = filter_df[filter_df["assembly_accession"].isin(accessions)]
 
-        return filter_df["assembly_accession"].to_list()
+        return filter_df["assembly_accession"].to_list() if accessions else []
 
     def filter_assembly_level(self, accessions=[], levels=[]):
         if not levels:
@@ -349,7 +349,7 @@ class AssemblySummary:
         if accessions:
             filter_df = filter_df[filter_df["assembly_accession"].isin(accessions)]
 
-        return filter_df["assembly_accession"].to_list()
+        return filter_df["assembly_accession"].to_list() if accessions else []
 
     def select_microbiome(self):
         accessions = self.filter_accession_by_group(groups=self.microbial_grops)
@@ -489,7 +489,13 @@ def main():
             if set(lvl_ls) - set(asm_levels):
                 raise ImportError(f"assembly-level must be {','.join(asm_levels)}")
             else:
-                return lvl_ls
+                lvl_map = dict(
+                    zip(
+                        ["chromosome", "complete", "contig", "scaffold"],
+                        ["Chromosome", "Complete Genome", "Contig", "Scaffold"],
+                    )
+                )
+                return [lvl_map[lvl] for lvl in lvl_ls]
 
         def check_refseq_category(str_category):
             cat_ls = split_comma(str_category)
@@ -720,6 +726,7 @@ def main():
         else:
             with open(args.taxid_list, "r") as f:
                 taxids = [row.strip("\n ") for row in f.readlines() if row.strip("\n ")]
+
         accessions = asmsum.filter_accession_by_taxid(taxids=taxids)
 
     elif args.groups:
